Module local_builder

Module local_builder 

Structs

LocalBuildParams
Parameters for local instruction building.
LocalBuildResult
Result of local instruction building.
TokenEntry
A token entry in the dynamic registry.

Enums

TokenId
Token identifier — symbol or Pubkey.

Functions

get_all_tokens
Get all unique tokens in the registry, sorted by USD liquidity.
get_token
Look up a token by symbol or mint string.
is_registry_synced
Check if registry has been synced
local_build
Build begin_flash and end_flash instructions 100% locally.
sync_registry
Sync the token registry from the VAEA API.
update_registry_from_capacity
Update the registry from a vec of TokenCapacity (from /v1/capacity). Called by sync_registry() and by WarmCache on each refresh.